==> javie-0.3.12-src.tar.gz: javie-0.3.12-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/exprelems/ColorProperty.java <==
/*
 * Copyright (c) 2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.exprelems;

import ch.kuramo.javie.api.Color;

public abstract class ColorProperty {

	public abstract Color getValue();

	public abstract Color valueAtTime(double t);

	public double getR() {
		return getValue().r;
	}

	public double getG() {
		return getValue().g;
	}

	public double getB() {
		return getValue().b;
	}

	public double getA() {
		return getValue().a;
	}

	@Override
	public String toString() {
		Color value = getValue();
		StringBuilder sb = new StringBuilder();
		sb.append(value.r).append(',');
		sb.append(value.g).append(',');
		sb.append(value.b).append(',');
		sb.append(value.a);
		return sb.toString();
	}

}

==> javie-0.5.1-src.tar.gz: javie-0.5.1-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/exprelems/ColorProperty.java <==
/*
 * Copyright (c) 2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.exprelems;

import ch.kuramo.javie.api.Color;

public abstract class ColorProperty {

	public abstract Color getValue();

	public abstract Color valueAtTime(double t);

	public double getR() {
		return getValue().r;
	}

	public double getG() {
		return getValue().g;
	}

	public double getB() {
		return getValue().b;
	}

	public double getA() {
		return getValue().a;
	}

	public double getRawRed() {
		return getValue().rawRed;
	}

	public double getRawGreen() {
		return getValue().rawGreen;
	}

	public double getRawBlue() {
		return getValue().rawBlue;
	}

	public double getRawAlpha() {
		return getValue().rawAlpha;
	}

	@Override
	public String toString() {
		Color value = getValue();
		StringBuilder sb = new StringBuilder();
		sb.append(value.r).append(',');
		sb.append(value.g).append(',');
		sb.append(value.b).append(',');
		sb.append(value.a);
		return sb.toString();
	}

}
